@@ -20,7 +20,7 @@ use Types::Standard qw/ Bool CodeRef HashRef Maybe Tuple /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.3.2';
+our $VERSION = 'v0.4.0';
 
 
 
@@ -160,10 +160,20 @@ has link_template => (
 
 
 has preload_template => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => CodeRef,
     builder => sub {
-        return sub { sprintf('<link rel="preload" as="style" href="%s" onload="this.onload=null;this.rel=\'stylesheet\'">', @_) },
+        my ($self) = @_;
+        if ($self->simple) {
+            return sub {
+                sprintf('<link rel="preload" as="style" href="%s">' .
+                        '<link rel="stylesheet" href="%s" media="print" onload="this.media=\'all\';this.onload=null;">',
+                        $_[0], $_[0])
+            }
+        }
+        else {
+            return sub { sprintf('<link rel="preload" as="style" href="%s" onload="this.onload=null;this.rel=\'stylesheet\'">', $_[0]) };
+        }
     },
 );
 
@@ -188,6 +198,13 @@ has log => (
 );
 
 
+has simple => (
+    is      => 'ro',
+    isa     => Bool,
+    default => 0,
+);
+
+
 sub check {
     my ($self) = @_;
 
@@ -288,7 +305,7 @@ sub deferred_link_html {
 
         $buffer .= "<script>" .
             $self->preload_script->slurp_raw .
-            "</script>";
+            "</script>" unless $self->simple;
 
     }
 
@@ -327,7 +344,7 @@ HTML::DeferableCSS - Simplify management of stylesheets in your HTML
 
 =head1 VERSION
 
-version v0.3.2
+version v0.4.0
 
 =head1 SYNOPSIS
 
@@ -337,6 +354,7 @@ version v0.3.2
       css_root      => '/var/www/css',
       url_base_path => '/css',
       inline_max    => 512,
+      simple  => 1,
       aliases => {
         reset => 1,
         jqui  => 'jquery-ui',
@@ -366,8 +384,8 @@ to something like
 
   <link rel="preload" as="stylesheet" href="....">
 
-but this is not well supported by all web browsers. So a web page
-needs some L<JavaScript|https://github.com/filamentgroup/loadCSS>
+but this is not well supported by all web browsers.  So a web page needs
+to use some L<JavaScript|https://github.com/filamentgroup/loadCSS>
 to handle this, as well as a C<noscript> block as a fallback.
 
 This module allows you to simplify the management of stylesheets for a
@@ -566,6 +584,16 @@ or even integrate this with your own logging system:
 
   log => sub { $logger->log(@_) },
 
+=head2 simple
+
+When true, this enables a simpler method of using deferable CSS,
+without the need for the C<loadCSS> script.
+
+It is false by default, for backwards compatability. But it is
+recommended that you set this to true.
+
+See L<https://www.filamentgroup.com/lab/load-css-simpler/>.
+
 =head1 METHODS
 
 =head2 check
